@@ -1,14 +1,14 @@
 package TestFor::Code::TidyAll::Git;
 
-use Capture::Tiny qw(capture capture_stderr);
+use Capture::Tiny            qw(capture capture_stderr);
 use Code::TidyAll::Git::Util qw(git_files_to_commit git_modified_files);
-use Code::TidyAll::Util qw(tempdir_simple);
+use Code::TidyAll::Util      qw(tempdir_simple);
 use Code::TidyAll;
 use File::pushd qw(pushd);
 use File::Spec;
-use FindBin qw( $Bin );
+use FindBin             qw( $Bin );
 use IPC::System::Simple qw(capturex runx);
-use Path::Tiny qw(path);
+use Path::Tiny          qw(path);
 use Test::Class::Most parent => 'TestHelper::Test::Class';
 use Try::Tiny;
 
@@ -343,7 +343,7 @@ sub _make_working_dir_and_repo {
 
     # This dir doesn't exist unless there's a git dir template that includes
     # the hooks subdir.
-    $hooks_dir->mkpath( 0, 0755 );
+    $hooks_dir->mkpath( { verbose => 0, mode => 0755 } );
     ok( -d $_, "$_ exists" ) for ( $work_dir, $hooks_dir );
 
     my $pushd = pushd($work_dir);
